@@ -36,7 +36,6 @@
 
 #include "libseahorse/seahorse-progress.h"
 #include "libseahorse/seahorse-util.h"
-#include "libseahorse/seahorse-passphrase.h"
 
 #include <gcr/gcr.h>
 
@@ -69,7 +68,7 @@ static gpgme_error_t
 passphrase_get (gconstpointer dummy, const gchar *passphrase_hint,
                 const char* passphrase_info, int flags, int fd)
 {
-	GtkDialog *dialog;
+	SeahorsePassphrasePrompt *dialog;
 	gpgme_error_t err;
 	gchar **split_uid = NULL;
 	gchar *label = NULL;
@@ -90,9 +89,9 @@ passphrase_get (gconstpointer dummy, const gchar *passphrase_hint,
 
 	if (split_uid && split_uid[0] && split_uid[1]) {
 		if (flags & SEAHORSE_PASS_NEW)
-			label = g_strdup_printf (_("Enter new passphrase for '%s'"), split_uid[1]);
+			label = g_strdup_printf (_("Enter new passphrase for “%s”"), split_uid[1]);
 		else
-			label = g_strdup_printf (_("Enter passphrase for '%s'"), split_uid[1]);
+			label = g_strdup_printf (_("Enter passphrase for “%s”"), split_uid[1]);
 	} else {
 		if (flags & SEAHORSE_PASS_NEW)
 			label = g_strdup (_("Enter new passphrase"));
@@ -102,14 +101,14 @@ passphrase_get (gconstpointer dummy, const gchar *passphrase_hint,
 
 	g_strfreev (split_uid);
 
-	dialog = seahorse_passphrase_prompt_show (_("Passphrase"), errmsg ? errmsg : label,
+	dialog = seahorse_passphrase_prompt_show_dialog (_("Passphrase"), errmsg ? errmsg : label,
 	                                          NULL, NULL, confirm);
 	g_free (label);
 	g_free (errmsg);
 
-	switch (gtk_dialog_run (dialog)) {
+	switch (gtk_dialog_run (GTK_DIALOG (dialog))) {
 	case GTK_RESPONSE_ACCEPT:
-		pass = seahorse_passphrase_prompt_get (dialog);
+		pass = seahorse_passphrase_prompt_get_text (dialog);
 		seahorse_util_printf_fd (fd, "%s\n", pass);
 		err = GPG_OK;
 		break;
@@ -806,6 +805,11 @@ seahorse_gpgme_keyring_get_label (SeahorsePlace *place)
 	return g_strdup (_("GnuPG keys"));
 }
 
+static void
+seahorse_gpgme_keyring_set_label (SeahorsePlace *place, const char *label)
+{
+}
+
 static gchar *
 seahorse_gpgme_keyring_get_description (SeahorsePlace *place)
 {
@@ -863,6 +867,24 @@ seahorse_gpgme_keyring_get_property (GObject *obj,
 	}
 }
 
+static void
+seahorse_gpgme_keyring_set_property (GObject *obj,
+                                     guint prop_id,
+                                     const GValue *value,
+                                     GParamSpec *pspec)
+{
+	SeahorsePlace *place = SEAHORSE_PLACE (obj);
+
+	switch (prop_id) {
+	case PROP_LABEL:
+		seahorse_gpgme_keyring_set_label (place, g_value_get_boxed (value));
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, prop_id, pspec);
+		break;
+	}
+}
+
 static void
 seahorse_gpgme_keyring_dispose (GObject *object)
 {
@@ -916,6 +938,7 @@ seahorse_gpgme_keyring_class_init (SeahorseGpgmeKeyringClass *klass)
 
 	gobject_class = G_OBJECT_CLASS (klass);
 	gobject_class->get_property = seahorse_gpgme_keyring_get_property;
+	gobject_class->set_property = seahorse_gpgme_keyring_set_property;
 	gobject_class->dispose = seahorse_gpgme_keyring_dispose;
 	gobject_class->finalize = seahorse_gpgme_keyring_finalize;
 
@@ -937,6 +960,7 @@ seahorse_gpgme_keyring_place_iface (SeahorsePlaceIface *iface)
 	iface->get_description = seahorse_gpgme_keyring_get_description;
 	iface->get_icon = seahorse_gpgme_keyring_get_icon;
 	iface->get_label = seahorse_gpgme_keyring_get_label;
+	iface->set_label = seahorse_gpgme_keyring_set_label;
 	iface->get_uri = seahorse_gpgme_keyring_get_uri;
 }
 
